@@ -66,6 +66,8 @@ recommend_data <- c('library("worcs")',
 #' @importFrom prereg vantveer_prereg
 # @importFrom renv init
 worcs_project <- function(path = "worcs_project", manuscript = "APA6", preregistration = "COS", add_license = "CC_BY_4.0", use_renv = TRUE, remote_repo = "https", verbose = TRUE, ...) {
+  cl <- match.call(expand.dots = FALSE)
+
   # collect inputs
   manuscript <- tolower(manuscript)
   preregistration <- tolower(preregistration)
@@ -112,60 +114,9 @@ worcs_project <- function(path = "worcs_project", manuscript = "APA6", preregist
 
   # Begin manuscript
   if(!manuscript == "none"){
-    tryCatch({
-      # Construct path to filename and create directory
-      man_dir_rel <- "manuscript"
-      man_dir_abs <- file.path(path, man_dir_rel)
-      man_fn_rel <- file.path(man_dir_rel, "manuscript.Rmd")
-      man_fn_abs <- file.path(man_dir_abs, "manuscript.Rmd")
-      dir.create(man_dir_abs)
-      switch(manuscript,
-             apa6 = create_man_papaja(man_fn_abs, remote_repo = remote_repo),
-             acm_article = create_man_rticles(man_fn_abs, "acm_article", remote_repo = remote_repo),
-             acs_article = create_man_rticles(man_fn_abs, "acs_article", remote_repo = remote_repo),
-             aea_article = create_man_rticles(man_fn_abs, "aea_article", remote_repo = remote_repo),
-             agu_article = create_man_rticles(man_fn_abs, "agu_article", remote_repo = remote_repo),
-             amq_article = create_man_rticles(man_fn_abs, "amq_article", remote_repo = remote_repo),
-             ams_article = create_man_rticles(man_fn_abs, "ams_article", remote_repo = remote_repo),
-             asa_article = create_man_rticles(man_fn_abs, "asa_article", remote_repo = remote_repo),
-             biometrics_article = create_man_rticles(man_fn_abs, "biometrics_article", remote_repo = remote_repo),
-             copernicus_article = create_man_rticles(man_fn_abs, "copernicus_article", remote_repo = remote_repo),
-             ctex = create_man_rticles(man_fn_abs, "ctex", remote_repo = remote_repo),
-             elsevier_article = create_man_rticles(man_fn_abs, "elsevier_article", remote_repo = remote_repo),
-             frontiers_article = create_man_rticles(man_fn_abs, "frontiers_article", remote_repo = remote_repo),
-             ieee_article = create_man_rticles(man_fn_abs, "ieee_article", remote_repo = remote_repo),
-             joss_article = create_man_rticles(man_fn_abs, "joss_article", remote_repo = remote_repo),
-             jss_article = create_man_rticles(man_fn_abs, "jss_article", remote_repo = remote_repo),
-             mdpi_article = create_man_rticles(man_fn_abs, "mdpi_article", remote_repo = remote_repo),
-             mnras_article = create_man_rticles(man_fn_abs, "mnras_article", remote_repo = remote_repo),
-             oup_article = create_man_rticles(man_fn_abs, "oup_article", remote_repo = remote_repo),
-             peerj_article = create_man_rticles(man_fn_abs, "peerj_article", remote_repo = remote_repo),
-             plos_article = create_man_rticles(man_fn_abs, "plos_article", remote_repo = remote_repo),
-             pnas_article = create_man_rticles(man_fn_abs, "pnas_article", remote_repo = remote_repo),
-             rjournal_article = create_man_rticles(man_fn_abs, "rjournal_article", remote_repo = remote_repo),
-             rsos_article = create_man_rticles(man_fn_abs, "rsos_article", remote_repo = remote_repo),
-             sage_article = create_man_rticles(man_fn_abs, "sage_article", remote_repo = remote_repo),
-             sim_article = create_man_rticles(man_fn_abs, "sim_article", remote_repo = remote_repo),
-             springer_article = create_man_rticles(man_fn_abs, "springer_article", remote_repo = remote_repo),
-             tf_article = create_man_rticles(man_fn_abs, "tf_article", remote_repo = remote_repo),
-             create_man_github(man_fn_abs, remote_repo = remote_repo)
-      )
-      # Add references.bib
-      copy_resources(which_files = "references.bib", path = man_dir_abs)
-      bibfiles <- list.files(path = man_dir_abs, pattern = ".bib$", full.names = TRUE)
-      if(length(bibfiles) > 1){
-        worcs_ref <- readLines(bibfiles[endsWith(bibfiles, "references.bib")], encoding = "UTF-8")
-        bib_text <- do.call(c, lapply(bibfiles[!endsWith(bibfiles, "references.bib")], readLines, encoding = "UTF-8"))
-        invisible(file.remove(bibfiles))
-        write_as_utf(c(worcs_ref, bib_text), file.path(man_dir_abs, "references.bib"))
-      }
-      write_worcsfile(filename = file.path(path, ".worcs"),
-                      entry_point = man_fn_rel,
-                      modify = TRUE)
-      col_message("Creating manuscript files.")
-    }, error = function(e){
-      col_message("Creating manuscript files.", success = FALSE)
-    })
+    cl[[1L]] <- quote(worcs::add_manuscript)
+    names(cl)[which(names(cl) == "path")] <- "worcs_directory"
+    eval(cl, parent.frame())
   } else {
     write_as_utf(recommend_data, file.path(path, "run_me.R"))
     write_worcsfile(filename = file.path(path, ".worcs"),
@@ -416,3 +367,114 @@ nice_tab <- function(tab){
   tab <- tab[c(1, nrow(tab), 2:(nrow(tab)-1)), ]
   apply(tab, 1, paste, collapse = " | ")
 }
+
+#' @title Add Rmarkdown manuscript
+#' @description Adds an Rmarkdown manuscript to a 'worcs' project.
+#' @param worcs_directory Character, indicating the directory
+#' in which to create the manuscript files. Default: '.', which points to the
+#' current working directory.
+#' @param manuscript Character, indicating what template to use for the
+#' 'R Markdown' manuscript. Default: 'APA6'. Available choices include:
+#' \code{"APA6", "github_document", "None", "ams_article", "asa_article",
+#' "biometrics_article", "copernicus_article", "ctex", "elsevier_article",
+#' "frontiers_article", "ieee_article", "joss_article", "jss_article",
+#' "mdpi_article", "mnras_article", "oup_article", "peerj_article",
+#' "plos_article", "pnas_article", "rjournal_article", "rsos_article",
+#' "sage_article", "sim_article", "springer_article", "tf_article"}.
+#' For more information about \code{APA6}, see the 'papaja' package, at
+#' <https://github.com/crsh/papaja>.
+#' For more information about \code{github_document}, see
+#' \code{\link[rmarkdown]{github_document}}. The remaining formats are
+#' documented in the 'rticles' package.
+#' @param remote_repo Character, 'https' link to the remote repository for
+#' this project. This link should have the form \code{https://[...].git}.
+#' If a valid remote repository link is provided, a commit will
+#' be made containing the 'README.md' file, and will be pushed to the remote
+#' repository. Default: 'https'. When no 'https' address is provided, an 'SSH'
+#' address of the form \code{git@[...].git} is also accepted.
+#' @param verbose Logical. Whether or not to print messages to the console
+#' during project creation. Default: TRUE
+#' @param ... Additional arguments passed to and from functions.
+#' @return No return value. This function is called for its side effects.
+#' @examples
+#' the_test <- "worcs_manuscript"
+#' old_wd <- getwd()
+#' dir.create(file.path(tempdir(), the_test))
+#' file.create(file.path(tempdir(), the_test, ".worcs"))
+#' add_manuscript(file.path(tempdir(), the_test),
+#'               manuscript = "github_document")
+#' setwd(old_wd)
+#' unlink(file.path(tempdir(), the_test))
+#' @rdname add_manuscript
+#' @export
+#' @importFrom rmarkdown draft
+#' @importFrom prereg vantveer_prereg
+# @importFrom renv init
+add_manuscript <- function(worcs_directory = ".", manuscript = "APA6", remote_repo = "https", verbose = TRUE, ...) {
+  # collect inputs
+  dn_worcs <- dirname(check_recursive(file.path(normalizePath(worcs_directory), ".worcs")))
+  fn_worcs <- file.path(dn_worcs, ".worcs")
+
+  manuscript <- tolower(manuscript)
+  dots <- list(...)
+  # ensure path exists
+  worcs_directory <- normalizePath(worcs_directory)
+  # Check if valid Git signature exists
+
+  # Begin manuscript
+    tryCatch({
+      # Construct path to filename and create directory
+      man_dir_rel <- "manuscript"
+      man_dir_abs <- file.path(worcs_directory, man_dir_rel)
+      man_fn_rel <- file.path(man_dir_rel, "manuscript.Rmd")
+      man_fn_abs <- file.path(man_dir_abs, "manuscript.Rmd")
+      dir.create(man_dir_abs)
+      switch(manuscript,
+             apa6 = create_man_papaja(man_fn_abs, remote_repo = remote_repo),
+             acm_article = create_man_rticles(man_fn_abs, "acm_article", remote_repo = remote_repo),
+             acs_article = create_man_rticles(man_fn_abs, "acs_article", remote_repo = remote_repo),
+             aea_article = create_man_rticles(man_fn_abs, "aea_article", remote_repo = remote_repo),
+             agu_article = create_man_rticles(man_fn_abs, "agu_article", remote_repo = remote_repo),
+             amq_article = create_man_rticles(man_fn_abs, "amq_article", remote_repo = remote_repo),
+             ams_article = create_man_rticles(man_fn_abs, "ams_article", remote_repo = remote_repo),
+             asa_article = create_man_rticles(man_fn_abs, "asa_article", remote_repo = remote_repo),
+             biometrics_article = create_man_rticles(man_fn_abs, "biometrics_article", remote_repo = remote_repo),
+             copernicus_article = create_man_rticles(man_fn_abs, "copernicus_article", remote_repo = remote_repo),
+             ctex = create_man_rticles(man_fn_abs, "ctex", remote_repo = remote_repo),
+             elsevier_article = create_man_rticles(man_fn_abs, "elsevier_article", remote_repo = remote_repo),
+             frontiers_article = create_man_rticles(man_fn_abs, "frontiers_article", remote_repo = remote_repo),
+             ieee_article = create_man_rticles(man_fn_abs, "ieee_article", remote_repo = remote_repo),
+             joss_article = create_man_rticles(man_fn_abs, "joss_article", remote_repo = remote_repo),
+             jss_article = create_man_rticles(man_fn_abs, "jss_article", remote_repo = remote_repo),
+             mdpi_article = create_man_rticles(man_fn_abs, "mdpi_article", remote_repo = remote_repo),
+             mnras_article = create_man_rticles(man_fn_abs, "mnras_article", remote_repo = remote_repo),
+             oup_article = create_man_rticles(man_fn_abs, "oup_article", remote_repo = remote_repo),
+             peerj_article = create_man_rticles(man_fn_abs, "peerj_article", remote_repo = remote_repo),
+             plos_article = create_man_rticles(man_fn_abs, "plos_article", remote_repo = remote_repo),
+             pnas_article = create_man_rticles(man_fn_abs, "pnas_article", remote_repo = remote_repo),
+             rjournal_article = create_man_rticles(man_fn_abs, "rjournal_article", remote_repo = remote_repo),
+             rsos_article = create_man_rticles(man_fn_abs, "rsos_article", remote_repo = remote_repo),
+             sage_article = create_man_rticles(man_fn_abs, "sage_article", remote_repo = remote_repo),
+             sim_article = create_man_rticles(man_fn_abs, "sim_article", remote_repo = remote_repo),
+             springer_article = create_man_rticles(man_fn_abs, "springer_article", remote_repo = remote_repo),
+             tf_article = create_man_rticles(man_fn_abs, "tf_article", remote_repo = remote_repo),
+             create_man_github(man_fn_abs, remote_repo = remote_repo)
+      )
+      # Add references.bib
+      copy_resources(which_files = "references.bib", path = man_dir_abs)
+      bibfiles <- list.files(path = man_dir_abs, pattern = ".bib$", full.names = TRUE)
+      if(length(bibfiles) > 1){
+        worcs_ref <- readLines(bibfiles[endsWith(bibfiles, "references.bib")], encoding = "UTF-8")
+        bib_text <- do.call(c, lapply(bibfiles[!endsWith(bibfiles, "references.bib")], readLines, encoding = "UTF-8"))
+        invisible(file.remove(bibfiles))
+        write_as_utf(c(worcs_ref, bib_text), file.path(man_dir_abs, "references.bib"))
+      }
+      write_worcsfile(filename = fn_worcs,
+                      entry_point = man_fn_rel,
+                      modify = TRUE)
+      col_message("Creating manuscript files.")
+    }, error = function(e){
+      col_message("Creating manuscript files.", success = FALSE)
+    })
+  # End manuscript
+}
